Engine

Struct Engine 

pub struct Engine { /* private fields */ }
Run CI for a project once.

Implementations

Source

impl Engine

pub fn new() -> Result<Self, EngineError>

Create a new engine and prepare for actually running CI. This may fail, for various reasons, such as the configuration file not existing. The caller should handle the error in some suitable way, such as report that to its stderr, and exit non-zero.

pub fn config(&self) -> &Config

Return config that has been loaded for the engine.

pub fn run(&mut self) -> Result<bool, EngineError>

Set up and run CI on a project once: read the trigger request from stdin, write responses to stdout. Update node admin log with any problems that aren’t inherent in the git repository (those go into the run log).

pub fn report(&mut self) -> Result<(), EngineError>

Report results to caller (via stdout) and to users (via report on web page).